import 'dart:async';
import 'dart:convert';

import 'package:blusalt_identity/model/initialization_response.dart';
import 'package:blusalt_identity/network/network_client.dart';
import 'package:blusalt_identity/services.dart';

class BlusaltSDK {
  static final BlusaltSDK _instance = BlusaltSDK._internal();
  static ApiCredentials apiCredentials;
  static String _bundleID;
  static List<ServiceType> _services;

  String get bundleID => _bundleID;
  static List<ServiceType> get services => _services;

  factory BlusaltSDK({ApiCredentials credentials}) {
    apiCredentials = credentials;
    return _instance;
  }

  static Future<dynamic> initializeSDK(ApiCredentials credentials) {
    BlusaltSDK(credentials: credentials);
    var client = new HttpClient();
    var future = client.initializeSDK(credentials);
    future.then((onValue) {
      InitializationResponse response =
          InitializationResponse.fromJson(jsonDecode(onValue.body));
      if (response.statusCode == 200) {
        var services = response.result.services;
        _bundleID = response.result.bundleCallId;
        _services = _getEnableServices(response.result.services);

        return Future.value(response);
      } else
        return future;
    });
    return future;

    //return client.initializeSDK(apiCredentials);
  }

  BlusaltSDK._internal() {}

  static List<ServiceType> _getEnableServices(List<Services> services) {
    var list = List();
    services.forEach((it) {
      list.add(_getServiceFromLabel(it.serviceLabel));
    });
    return list;
  }

  static ServiceType _getServiceFromLabel(String label) {
    switch (label) {
      case "(BVN) Bank Verification Number":
        return ServiceType.bvnVerification;
      case "(NIN) National Identity Number":
        return ServiceType.ninVerification;
      case "(PVC) Permanent Voters Card":
        return ServiceType.pvcVerification;
      case "(DL) Drivers Licence":
        return ServiceType.dlVerification;
      case "(NIP) Nigerian International Passport":
        return ServiceType.nipVerification;
      default:
        return null;
    }
  }
}
